@@ -1,3 +1,11 @@
+'''
+Author: HaoTian Qi
+Date: 2020-12-19 15:13:29
+Description: logger
+LastEditTime: 2020-12-19 16:53:16
+LastEditors: HaoTian Qi
+FilePath: /htutil/htutil/log.py
+'''
 import re
 import inspect
 import datetime
@@ -6,6 +14,7 @@ _format = '${var_name} = ${value};${time};${file_name}:${line_number}'
 
 
 def config(format: str):
+    global _format
     _format = format
 
 
@@ -53,11 +62,10 @@ def callback_example(string: str):
 def main():
     a = 3
     p(a)
-
     p(a-1)
-
     register_p_callback(callback_example)
-
+    config(format = '${var_name} = ${value} ### ${time} ### ${file_name}:${line_number}')
+    p(a)
     b = bob()
     p(b.a)
 
